@@ -52,7 +52,7 @@ impl Tg4Contract {
     }
 
     pub fn remove_hook<T: Into<String>>(&self, addr: T) -> StdResult<SubMsg> {
-        let msg = Tg4ExecuteMsg::AddHook { addr: addr.into() };
+        let msg = Tg4ExecuteMsg::RemoveHook { addr: addr.into() };
         self.encode_msg(msg)
     }
 
@@ -86,13 +86,13 @@ impl Tg4Contract {
         Ok(res.hooks)
     }
 
-    /// Read the total weight
-    pub fn total_weight(&self, querier: &QuerierWrapper) -> StdResult<u64> {
+    /// Read the total points
+    pub fn total_points(&self, querier: &QuerierWrapper) -> StdResult<u64> {
         let query = self.encode_raw_query(TOTAL_KEY.as_bytes());
         querier.query(&query)
     }
 
-    /// Check if this address is a member, and if so, with which weight
+    /// Check if this address is a member, and if so, with which points
     pub fn is_member(&self, querier: &QuerierWrapper, addr: &Addr) -> StdResult<Option<u64>> {
         let path = member_key(addr.as_ref());
         let query = self.encode_raw_query(path);
@@ -124,19 +124,19 @@ impl Tg4Contract {
     pub fn is_voting_member(&self, querier: &QuerierWrapper, member: &str) -> StdResult<u64> {
         self.is_member(querier, &Addr::unchecked(member))?.map_or(
             Err(StdError::generic_err("Unauthorized: not member of a group")),
-            |member_weight| {
-                if member_weight < 1 {
+            |member_points| {
+                if member_points < 1 {
                     Err(StdError::generic_err(
                         "Unauthorized: member doesn't have voting power",
                     ))
                 } else {
-                    Ok(member_weight)
+                    Ok(member_points)
                 }
             },
         )
     }
 
-    /// Check if this address was a member, and if its weight is >= 1
+    /// Check if this address was a member, and if its points is >= 1
     pub fn was_voting_member<T: Into<String>>(
         &self,
         querier: &QuerierWrapper,
@@ -148,20 +148,20 @@ impl Tg4Contract {
                 "Unauthorized: wasn't member of a group at block height: {}",
                 height
             ))),
-            |member_weight| {
-                if member_weight < 1 {
+            |member_points| {
+                if member_points < 1 {
                     Err(StdError::generic_err(format!(
                         "Unauthorized: member didn't have voting power at block height: {}",
                         height
                     )))
                 } else {
-                    Ok(member_weight)
+                    Ok(member_points)
                 }
             },
         )
     }
 
-    /// Return the member's weight at the given snapshot - requires a smart query
+    /// Return the member's points at the given snapshot - requires a smart query
     pub fn member_at_height<T: Into<String>>(
         &self,
         querier: &QuerierWrapper,
@@ -173,7 +173,7 @@ impl Tg4Contract {
             at_height: Some(height),
         })?;
         let res: MemberResponse = querier.query(&query)?;
-        Ok(res.weight)
+        Ok(res.points)
     }
 
     pub fn list_members(
@@ -187,19 +187,19 @@ impl Tg4Contract {
         Ok(res.members)
     }
 
-    pub fn list_members_by_weight(
+    pub fn list_members_by_points(
         &self,
         querier: &QuerierWrapper,
         start_after: Option<Member>,
         limit: Option<u32>,
     ) -> StdResult<Vec<Member>> {
         let query =
-            self.encode_smart_query(Tg4QueryMsg::ListMembersByWeight { start_after, limit })?;
+            self.encode_smart_query(Tg4QueryMsg::ListMembersByPoints { start_after, limit })?;
         let res: MemberListResponse = querier.query(&query)?;
         Ok(res.members)
     }
 
-    /// This will make some queires to ensure that the target contract is tg4-compatible.
+    /// This will make some queries to ensure that the target contract is tg4-compatible.
     /// It returns `true` iff it appears to be compatible.
     pub fn is_tg4(&self, querier: &QuerierWrapper) -> bool {
         self.list_members(querier, None, Some(1)).is_ok()
